==> mx-packageinstaller-pkglist_19.01.01.tar.xz: mx-packageinstaller-pkglist/xmms.pm <==
<?xml version="1.0"?>
<app>

<category>
Audio
</category>

<name>
XMMS
</name>

<description>
   <am>multimedia player modelled on winamp</am>
   <ca>Reproductor multimèdia modelat en winamp</ca>
   <cs>multimedia player modelled on winamp</cs>
   <da>multimedia player modelled on winamp</da>
   <de>Multimedia-Player nach dem Vorbild von Winamp</de>
   <el>αναπαραγωγή πολυμέσων με βάση το winamp</el>
   <en>multimedia player modelled on winamp</en>
   <es>reproductor multimedia estilo winamp</es>
   <fi>multimedia player modelled on winamp</fi>
   <fr>Lecteur multimédia inspiré de winamp</fr>
   <hi>multimedia player modelled on winamp</hi>
   <hr>multimedia player modelled on winamp</hr>
   <hu>multimedia player modelled on winamp</hu>
   <is>multimedia player modelled on winamp</is>
   <it>riproduttore multimediale simile a winamp</it>
   <ja>multimedia player modelled on winamp</ja>
   <kk>multimedia player modelled on winamp</kk>
   <lt>multimedia player modelled on winamp</lt>
   <nl>multimediaspeler gemodelleerd naar winamp</nl>
   <pl>multimedia player modelled on winamp</pl>
   <pt_BR>Reprodutor de multimídia semelhante ao winamp</pt_BR>
   <pt>Reprodutor de multimédia semelhante ao winamp</pt>
   <ro>multimedia player modelled on winamp</ro>
   <ru>Универсальный аудиоплеер наподобие WinAmp</ru>
   <sk>multimedia player modelled on winamp</sk>
   <sq>multimedia player modelled on winamp</sq>
   <sv>multimediaspelare formad efter winamp</sv>
   <tr>multimedia player modelled on winamp</tr>
   <uk>multimedia player modelled on winamp</uk>
   <zh_TW>multimedia player modelled on winamp</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>http://www.xmms.org/screenshots/main.gif</screenshot>

<preinstall>

</preinstall>

<install_package_names>
xmms
xmms-plugins-antix
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
xmms
xmms-plugins-antix
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.01.03.tar.xz: mx-packageinstaller-pkglist/xmms.pm <==
<?xml version="1.0"?>
<app>

<category>
Audio
</category>

<name>
XMMS
</name>

<description>
   <am>multimedia player modelled on winamp</am>
   <ar>multimedia player modelled on winamp</ar>
   <bg>multimedia player modelled on winamp</bg>
   <ca>Reproductor multimèdia modelat en winamp</ca>
   <cs>multimedia player modelled on winamp</cs>
   <da>multimedieafspiller som er udformet efter winamp</da>
   <de>Multimedia-Player nach dem Vorbild von Winamp</de>
   <el>αναπαραγωγή πολυμέσων με βάση το winamp</el>
   <en>multimedia player modelled on winamp</en>
   <es>reproductor multimedia estilo winamp</es>
   <et>multimedia player modelled on winamp</et>
   <eu>multimedia player modelled on winamp</eu>
   <fa>multimedia player modelled on winamp</fa>
   <fi>multimedia player modelled on winamp</fi>
   <fr>Lecteur multimédia inspiré de winamp</fr>
   <he_IL>multimedia player modelled on winamp</he_IL>
   <hi>multimedia player modelled on winamp</hi>
   <hr>multimedia player modelled on winamp</hr>
   <hu>multimedia player modelled on winamp</hu>
   <id>multimedia player modelled on winamp</id>
   <is>multimedia player modelled on winamp</is>
   <it>riproduttore multimediale simile a winamp</it>
   <ja_JP>multimedia player modelled on winamp</ja_JP>
   <ja>multimedia player modelled on winamp</ja>
   <kk>multimedia player modelled on winamp</kk>
   <ko>multimedia player modelled on winamp</ko>
   <lt>multimedia player modelled on winamp</lt>
   <mk>multimedia player modelled on winamp</mk>
   <nb>multimedia player modelled on winamp</nb>
   <nl>multimediaspeler gemodelleerd naar winamp</nl>
   <pl>multimedia player modelled on winamp</pl>
   <pt_BR>Reprodutor de multimídia semelhante ao winamp</pt_BR>
   <pt>Reprodutor de multimédia semelhante ao winamp</pt>
   <ro>multimedia player modelled on winamp</ro>
   <ru>Универсальный аудиоплеер наподобие WinAmp</ru>
   <sk>multimedia player modelled on winamp</sk>
   <sl>multimedia player modelled on winamp</sl>
   <sq>multimedia player modelled on winamp</sq>
   <sr>multimedia player modelled on winamp</sr>
   <sv>multimediaspelare formad efter winamp</sv>
   <tr>multimedia player modelled on winamp</tr>
   <uk>мультимедія програвач схожий на winamp</uk>
   <zh_CN>multimedia player modelled on winamp</zh_CN>
   <zh_TW>multimedia player modelled on winamp</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>http://www.xmms.org/screenshots/main.gif</screenshot>

<preinstall>

</preinstall>

<install_package_names>
xmms
xmms-plugins-antix
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
xmms
xmms-plugins-antix
</uninstall_package_names>
</app>
